@@ -17,7 +17,7 @@
   GNU General Public License for more details.
 
 */
-/* $Id: command_reply.c,v 1.89 2002/06/15 16:06:54 priikone Exp $ */
+/* $Id: command_reply.c,v 1.92 2002/06/29 18:07:29 priikone Exp $ */
 
 #include "serverincludes.h"
 #include "server_internal.h"
@@ -143,6 +143,7 @@ silc_server_command_process_error(SilcServerCommandReplyContext cmd,
 	if (client) {
 	  silc_server_remove_from_channels(server, NULL, client, TRUE, 
 					   NULL, TRUE);
+	  silc_idlist_del_data(client);
 	  silc_idlist_del_client(server->global_list, client);
 	}
 	silc_free(client_id);
@@ -566,7 +567,8 @@ silc_server_command_reply_identify_save(SilcServerCommandReplyContext cmd)
       /* We don't have that server anywhere, add it. */
       server_entry = silc_idlist_add_server(server->global_list, 
 					    strdup(name), 0,
-					    server_id, NULL, NULL);
+					    server_id, server->router,
+					    SILC_PRIMARY_ROUTE(server));
       if (!server_entry) {
 	silc_free(server_id);
 	goto error;
@@ -601,7 +603,7 @@ silc_server_command_reply_identify_save(SilcServerCommandReplyContext cmd)
       if (server->server_type != SILC_SERVER)
 	goto error;
       
-      /* We don't have that server anywhere, add it. */
+      /* We don't have that channel anywhere, add it. */
       channel = silc_idlist_add_channel(server->global_list, strdup(name),
 					SILC_CHANNEL_MODE_NONE, channel_id, 
 					server->router, NULL, NULL, 0);
@@ -693,7 +695,8 @@ SILC_SERVER_CMD_REPLY_FUNC(info)
       /* Add the server to global list */
       server_id = silc_id_dup(server_id, SILC_ID_SERVER);
       entry = silc_idlist_add_server(server->global_list, name, 0,
-				     server_id, NULL, NULL);
+				     server_id, cmd->sock->user_data,
+				     cmd->sock);
       if (!entry) {
 	silc_free(server_id);
 	goto out;
@@ -1061,7 +1064,7 @@ SILC_SERVER_CMD_REPLY_FUNC(users)
 	goto out;
 
       idp = silc_id_payload_encode(channel_id, SILC_ID_CHANNEL);
-      silc_server_send_command(server, server->router->connection,
+      silc_server_send_command(server, SILC_PRIMARY_ROUTE(server),
 			       SILC_COMMAND_IDENTIFY, ++server->cmd_ident,
 			       1, 5, idp->data, idp->len);
       silc_buffer_free(idp);
