@@ -17,7 +17,7 @@
   GNU General Public License for more details.
 
 */
-/* $Id: idlist.c,v 1.72 2002/06/26 18:42:27 priikone Exp $ */
+/* $Id: idlist.c,v 1.75 2002/06/28 13:27:58 priikone Exp $ */
 
 #include "serverincludes.h"
 #include "idlist.h"
@@ -159,13 +159,13 @@ silc_idlist_find_server_by_id(SilcIDList id_list, SilcServerID *id,
 
   server = (SilcServerEntry)id_cache->context;
 
-  if (ret_entry)
-    *ret_entry = id_cache;
-
   if (server && registered && 
       !(server->data.status & SILC_IDLIST_STATUS_REGISTERED))
     return NULL;
 
+  if (ret_entry)
+    *ret_entry = id_cache;
+
   SILC_LOG_DEBUG(("Found"));
 
   return server;
@@ -187,13 +187,13 @@ silc_idlist_find_server_by_name(SilcIDList id_list, char *name,
 
   server = (SilcServerEntry)id_cache->context;
   
-  if (ret_entry)
-    *ret_entry = id_cache;
-
   if (server && registered &&
       !(server->data.status & SILC_IDLIST_STATUS_REGISTERED))
     return NULL;
 
+  if (ret_entry)
+    *ret_entry = id_cache;
+
   SILC_LOG_DEBUG(("Found"));
 
   return server;
@@ -239,13 +239,13 @@ silc_idlist_find_server_by_conn(SilcIDList id_list, char *hostname,
   
   silc_idcache_list_free(list);
 
-  if (ret_entry)
-    *ret_entry = id_cache;
-
   if (server && registered &&
       !(server->data.status & SILC_IDLIST_STATUS_REGISTERED))
     return NULL;
 
+  if (ret_entry)
+    *ret_entry = id_cache;
+
   SILC_LOG_DEBUG(("Found"));
 
   return server;
@@ -368,6 +368,8 @@ int silc_idlist_del_client(SilcIDList id_list, SilcClientEntry entry)
     if (!silc_idcache_del_by_context(id_list->clients, entry))
       return FALSE;
 
+    assert(!silc_hash_table_count(entry->channels));
+
     /* Free data */
     silc_free(entry->nickname);
     silc_free(entry->servername);
@@ -491,13 +493,13 @@ silc_idlist_find_client_by_id(SilcIDList id_list, SilcClientID *id,
 
   client = (SilcClientEntry)id_cache->context;
 
-  if (ret_entry)
-    *ret_entry = id_cache;
-
   if (client && registered &&
       !(client->data.status & SILC_IDLIST_STATUS_REGISTERED))
     return NULL;
 
+  if (ret_entry)
+    *ret_entry = id_cache;
+
   SILC_LOG_DEBUG(("Found"));
 
   return client;
@@ -568,6 +570,7 @@ void silc_idlist_client_destructor(SilcIDCache cache,
 
   client = (SilcClientEntry)entry->context;
   if (client) {
+    assert(!silc_hash_table_count(client->channels));
     silc_free(client->nickname);
     silc_free(client->username);
     silc_free(client->userinfo);
