@@ -49,6 +49,10 @@ typedef struct {
   SilcUInt32 detached;		          /* All clients detached */
   SilcUInt32 server_ops;		  /* All server operators */
   SilcUInt32 router_ops;		  /* All router operators */
+  /* More to add
+  SilcUInt32 secret_channels;
+  SilcUInt32 private_channels;
+  */
 
   /* General */
   SilcUInt32 conn_attempts;		  /* Connection attempts */
@@ -83,6 +87,7 @@ struct SilcServerStruct {
 				        router to a backup router. */
   unsigned int wait_backup    : 1;   /* Set if we are waiting for backup
 				        router to connect to us. */
+  unsigned int server_shutdown: 1;   /* Set when shutting down */
 
   SilcServerEntry router;	     /* Pointer to the primary router */
   unsigned long router_connect;	     /* Time when router was connected */
