@@ -16,7 +16,7 @@
   GNU General Public License for more details.
 
 */
-/* $Id: server_util.c,v 1.55 2002/06/26 18:42:28 priikone Exp $ */
+/* $Id: server_util.c,v 1.59 2002/06/30 08:03:45 priikone Exp $ */
 
 #include "serverincludes.h"
 #include "server_internal.h"
@@ -55,7 +55,7 @@ silc_server_remove_clients_channels(SilcServer server,
 
     /* Remove channel if this is last client leaving the channel, unless
        the channel is permanent. */
-    if (server->server_type == SILC_ROUTER &&
+    if (server->server_type != SILC_SERVER &&
 	silc_hash_table_count(channel->user_list) < 2) {
       if (silc_hash_table_find(channels, channel, NULL, NULL))
 	silc_hash_table_del(channels, channel);
@@ -87,7 +87,7 @@ silc_server_remove_clients_channels(SilcServer server,
     /* If there is not at least one local user on the channel then we don't
        need the channel entry anymore, we can remove it safely, unless the
        channel is permanent channel */
-    if (server->server_type != SILC_ROUTER &&
+    if (server->server_type == SILC_SERVER &&
 	!silc_server_channel_has_local(channel)) {
       if (silc_hash_table_find(channels, channel, NULL, NULL))
 	silc_hash_table_del(channels, channel);
@@ -218,6 +218,7 @@ bool silc_server_remove_clients_by_server(SilcServer server,
 	  client->data.status &= ~SILC_IDLIST_STATUS_REGISTERED;
 	  id_cache->expire = SILC_ID_CACHE_EXPIRE_DEF;
 	} else {
+	  silc_idlist_del_data(client);
 	  silc_idlist_del_client(server->local_list, client);
 	}
 
@@ -277,6 +278,7 @@ bool silc_server_remove_clients_by_server(SilcServer server,
 	  client->data.status &= ~SILC_IDLIST_STATUS_REGISTERED;
 	  id_cache->expire = SILC_ID_CACHE_EXPIRE_DEF;
 	} else {
+	  silc_idlist_del_data(client);
 	  silc_idlist_del_client(server->global_list, client);
 	}
 
@@ -287,6 +289,21 @@ bool silc_server_remove_clients_by_server(SilcServer server,
     silc_idcache_list_free(list);
   }
 
+  /* Return now if we are shutting down */
+  if (server->server_shutdown) {
+    silc_hash_table_free(channels);
+
+    if (server_signoff) {
+      for (i = 0; i < argc; i++)
+	silc_free(argv[i]);
+      silc_free(argv);
+      silc_free(argv_lens);
+      silc_free(argv_types);
+      silc_hash_table_free(clients);
+    }
+    return TRUE;
+  }
+
   /* Send the SERVER_SIGNOFF notify */
   if (server_signoff) {
     SilcBuffer args, not;
@@ -1032,7 +1049,8 @@ SilcUInt32 silc_server_num_sockets_by_ip(SilcServer server, const char *ip,
   int i, count;
 
   for (i = 0, count = 0; i < server->config->param.connections_max; i++) {
-    if (server->sockets[i] && !strcmp(server->sockets[i]->ip, ip) &&
+    if (server->sockets[i] && !SILC_IS_LISTENER(server->sockets[i]) &&
+	!strcmp(server->sockets[i]->ip, ip) &&
 	server->sockets[i]->type == type)
       count++;
   }
@@ -1056,7 +1074,7 @@ SilcUInt32 silc_server_num_sockets_by_remote(SilcServer server,
     return 0;
 
   for (i = 0, count = 0; i < server->config->param.connections_max; i++) {
-    if (server->sockets[i] && 
+    if (server->sockets[i] && !SILC_IS_LISTENER(server->sockets[i]) &&
 	((ip && !strcmp(server->sockets[i]->ip, ip)) ||
 	 (hostname && !strcmp(server->sockets[i]->hostname, hostname))) &&
 	server->sockets[i]->port == port &&
@@ -1511,6 +1529,7 @@ void silc_server_kill_client(SilcServer server,
     }
 
     /* Remove remote client */
+    silc_idlist_del_data(remote_client);
     if (!silc_idlist_del_client(server->global_list, remote_client)) {
       /* Remove this client from watcher list if it is */
       silc_server_del_from_watcher_list(server, remote_client);
